@@ -3,6 +3,16 @@
 # This is kernel build script for debian squeeze's 2.6.32 kernel.
 #
 
+update_maintainer () {
+    for i in debian*/control debian*/control.stub*
+    do
+	cp -p $i $i.orig
+	sed -i -e 's/Maintainer: .*/Maintainer: Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>/' -- $i
+	touch -r $i.orig $i
+	rm $i.orig
+    done
+}
+
 die () {
     echo $1
     exit 1
@@ -28,9 +38,9 @@ apt-get -y install wget zlib1g-dev debian-keyring
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120610.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20120805.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120610.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120610.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120805.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120805.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -42,11 +52,13 @@ tar -jxf linux-source-2.6.32.tar.bz2
 
 # Apply patches and create kernel config.
 cd linux-source-2.6.32 || die "Can't chdir to linux-source-2.6.18/ ."
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120610.tar.gz || die "Can't extract patch."
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120805.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-2.6.32-debian-squeeze.diff || die "Can't apply patch."
 cat /boot/config-2.6.32-5-686 config.ccs > .config || die "Can't create config."
 
 # Start compilation.
+make-kpkg --append-to-version -5-686-ccs --revision `sed -e 's/ /-/' version.Debian` --initrd configure || die "Failed to build kernel package."
+update_maintainer
 make-kpkg --append-to-version -5-686-ccs --revision `sed -e 's/ /-/' version.Debian` --initrd binary-arch || die "Failed to build kernel package."
 
 # Generate meta packages.
