@@ -1,8 +1,18 @@
 #! /bin/sh
 #
-# This is kernel build script for ubuntu 11.04's 2.6.38 kernel.
+# This is kernel build script for ubuntu 10.04's 2.6.32 kernel.
 #
 
+update_maintainer () {
+    for i in debian*/control debian*/control.stub*
+    do
+	cp -p $i $i.orig
+	sed -i -e 's/Maintainer: .*/Maintainer: Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>/' -- $i
+	touch -r $i.orig $i
+	rm $i.orig
+    done
+}
+
 die () {
     echo $1
     exit 1
@@ -19,22 +29,23 @@ apt-get -y install wget
 # Download TOMOYO Linux patches.
 mkdir -p /root/rpmbuild/SOURCES/
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20120610.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20120805.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20120610.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120610.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20120805.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20120805.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
 apt-get -y install fakeroot build-essential || die "Can't install packages."
 apt-get build-dep linux || die "Can't install packages."
-apt-get source linux-source-2.6.38 || die "Can't install kernel source."
-for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-2.6.38/debian/control`; do apt-get -y install $i; done
+apt-get source linux-source-2.6.32 || die "Can't install kernel source."
+for i in `awk ' { if ( $1 != "Build-Depends:") next; $1 = ""; n = split($0, a, ","); for (i = 1; i <= n; i++) { split(a[i], b, " "); print b[1]; } } ' linux-2.6.32/debian/control`; do apt-get -y install $i; done
 
 # Apply patches and create kernel config.
-cd linux-2.6.38/ || die "Can't chdir to linux-2.6.38/ ."
-tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120610.tar.gz || die "Can't extract patch."
-patch -p1 < patches/ccs-patch-2.6.38-ubuntu-11.04.diff || die "Can't apply patch."
+cd linux-2.6.32/ || die "Can't chdir to linux-2.6.32/ ."
+update_maintainer
+tar -zxf /root/rpmbuild/SOURCES/ccs-patch-1.8.3-20120805.tar.gz || die "Can't extract patch."
+patch -p1 < patches/ccs-patch-2.6.32-ubuntu-10.04.diff || die "Can't apply patch."
 rm -fR patches/ specs/ || die "Can't delete patch."
 for i in `find debian.master/ -type f -name '*'${ORIGINAL_FLAVOUR}'*'`; do cp -p $i `echo $i | sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g'`; done
 for i in debian.master/config/*/config.common.*; do cat config.ccs >> $i; done
@@ -47,7 +58,7 @@ debian/rules debian/control || die "Can't update control."
 patch -p0 << "EOF" || die "Can't patch link-headers."
 --- debian/scripts/link-headers
 +++ debian/scripts/link-headers
-@@ -39,4 +39,19 @@
+@@ -39,4 +39,17 @@
  done
  )
  
@@ -59,10 +70,8 @@ patch -p0 << "EOF" || die "Can't patch link-headers."
 +	rm -f $hdrdir/include/linux/$i
 +	cp -p $i $hdrdir/include/linux/$i
 +    done
-+    rm -f $hdrdir/include/net $hdrdir/security
-+    cd ../
-+    tar -cf - net | tar -xf - -C $hdrdir/include/
-+    cd ../
++    rm -f $hdrdir/security
++    cd ../../
 +    tar -cf - security | tar -xf - -C $hdrdir
 +fi
 +
@@ -79,6 +88,7 @@ cd /usr/src/
 rm -fR linux-meta-*/
 apt-get source linux-meta
 cd linux-meta-*/
+update_maintainer
 sed -e 's/'${ORIGINAL_FLAVOUR}'/'${NEW_FLAVOUR}'/g' -- debian/control.d/${ORIGINAL_FLAVOUR} > debian/${NEW_FLAVOUR}
 rm -f debian/control.d/*
 mv debian/${NEW_FLAVOUR} debian/control.d/${NEW_FLAVOUR}
